@@ -8,14 +8,13 @@ use Math::GSL::Const qw/:all/;
 use Math::GSL::Errno qw/:all/;
 use Carp qw/croak/;
 use Config;
-use Data::Dumper;
 use Test::More;
-use Scalar::Util qw/looks_like_number/;
 our @EXPORT = qw();
 our @EXPORT_OK = qw( ok_similar ok_status  is_similar
                      is_similar_relative verify verify_results 
                      $GSL_MODE_DEFAULT $GSL_PREC_DOUBLE
                      $GSL_PREC_SINGLE $GSL_PREC_APPROX
+                     is_windows gsl_inf
                    );
 
 our %EXPORT_TAGS = ( 
@@ -24,15 +23,15 @@ our %EXPORT_TAGS = (
 
 our ($GSL_PREC_DOUBLE, $GSL_PREC_SINGLE, $GSL_PREC_APPROX ) = 0..2;
 our $GSL_MODE_DEFAULT = $GSL_PREC_DOUBLE;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 NAME
 
-Math::GSL - Perl interface to the  GNU Scientific Library (GSL) using SWIG
+Math::GSL - Perl interface to the  GNU Scientific Library (GSL) 
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -78,7 +77,6 @@ intuitive (but slightly slower) object-oriented interface.
     Math::GSL::Machine          - Machine Specific Information
     Math::GSL::Matrix           - NxM Matrices
     Math::GSL::Min              - Minimization
-    Math::GSL::Mode             - GSL Precision Modes
     Math::GSL::Monte            - Monte Carlo Integrations
     Math::GSL::Multifit         - Multivariable Fitting
     Math::GSL::Multimin         - Multivariable Minimization
@@ -161,7 +159,7 @@ the Summer of Code happen each year. You rock.
 
 =head1 DEDICATION
 
-This Perl module is dedicated in the memory of Nick Ing-Simmons.
+This Perl module is dedicated in memory of Nick Ing-Simmons.
 
 =head1 COPYRIGHT & LICENSE
 
@@ -184,10 +182,10 @@ sub subsystems
 {
     return sort qw/
         Diff         Machine      Statistics
-        Block        Eigen        Matrix        Poly 
+        Eigen        Matrix       Poly 
         BSpline      Errno        PowInt        
         CBLAS        FFT          Min           IEEEUtils
-        CDF          Fit          Mode          QRNG
+        CDF          Fit          QRNG
         Chebyshev    Monte        RNG           Vector
         Heapsort     Multifit     Randist       Roots     
         Combination  Histogram    Multimin      Wavelet
@@ -229,7 +227,8 @@ sub is_similar {
 }
 sub ok_status {
     my ($got, $expected) = @_;
-    ok( $got == $expected, gsl_strerror($expected) );
+    $expected ||= $GSL_SUCCESS;
+    ok( $got == $expected, gsl_strerror(int($got)) );
 }
 sub ok_similar {
     my ($x,$y, $msg, $eps) = @_;
@@ -269,7 +268,6 @@ sub verify_results
                 printf "difference : %.18g\n", $res;
                 printf "unexpected error of %.18g\n", $res-$eps if ($res-$eps>0);
             }
-
             if ($x =~ /nan|inf/i) {
                     ok( $expected eq $x, "'$expected'?='$x'" );
             } else { 
@@ -301,11 +299,14 @@ sub verify
     }
 }
 
+sub gsl_inf    { is_windows() ?  '1.\#INF' : 'inf' }
+
 sub _dump_result($)
 {
     my $r=shift;
     printf "result->err: %.18g\n", $r->{err};
     printf "result->val: %.18g\n", $r->{val};
 }
+sub is_windows() { $^O =~ /MSWin32/i }
 
 42;
